@@ -38,24 +38,30 @@ namespace SignOn
 class CreateAccount : public KJob
 {
     Q_OBJECT
+    Q_PROPERTY(QString providerName READ providerName WRITE setProviderName NOTIFY providerNameChanged)
 public:
+    explicit CreateAccount(QObject* parent = 0);
     explicit CreateAccount(const QString &providerName, QObject* parent = 0);
 
-    virtual void start();
+    QString providerName() const { return m_providerName; }
+    void setProviderName(const QString &name);
+    void start() Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void processSessionOwncloud();
-    void processSessionKTp();
-    void accountCreated();
     void processSession();
     void sessionError(const SignOn::Error &signOnError);
     void sessionResponse(const SignOn::SessionData &data);
     void info(const SignOn::IdentityInfo &info);
+    void pluginFinished(const QString &screenName, const QString &secret, const QVariantMap &map);
+    void pluginError(const QString &error);
 
-    void ktpDialogFinished(const QString &username, const QString &password, const QVariantMap &additionalData);
-    void ktpDialogError(const QString &error);
+Q_SIGNALS:
+    void providerNameChanged();
 
 private:
+    void loadPluginAndShowDialog(const QString &pluginName);
+
     QString m_providerName;
     Accounts::Manager *m_manager;
     Accounts::Account *m_account;
@@ -63,4 +69,4 @@ private:
     SignOn::Identity *m_identity;
     bool m_done;
 };
-#endif //CREATE_ACCOUNT_JOB_H
\ No newline at end of file
+#endif //CREATE_ACCOUNT_JOB_H
